==> aws-java-sdk-autoscaling-1.10.11-sources.jar: com/amazonaws/services/autoscaling/model/transform/EnabledMetricStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Enabled Metric StAX Unmarshaller
 */
public class EnabledMetricStaxUnmarshaller implements Unmarshaller<EnabledMetric, StaxUnmarshallerContext> {

    public EnabledMetric unmarshall(StaxUnmarshallerContext context) throws Exception {
        EnabledMetric enabledMetric = new EnabledMetric();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return enabledMetric;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Metric", targetDepth)) {
                    enabledMetric.setMetric(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Granularity", targetDepth)) {
                    enabledMetric.setGranularity(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return enabledMetric;
                }
            }
        }
    }

    private static EnabledMetricStaxUnmarshaller instance;
    public static EnabledMetricStaxUnmarshaller getInstance() {
        if (instance == null) instance = new EnabledMetricStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-autoscaling-1.10.34-sources.jar: com/amazonaws/services/autoscaling/model/transform/EnabledMetricStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.autoscaling.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.autoscaling.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * EnabledMetric StAX Unmarshaller
 */
public class EnabledMetricStaxUnmarshaller implements
        Unmarshaller<EnabledMetric, StaxUnmarshallerContext> {

    public EnabledMetric unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        EnabledMetric enabledMetric = new EnabledMetric();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return enabledMetric;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("Metric", targetDepth)) {
                    enabledMetric.setMetric(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("Granularity", targetDepth)) {
                    enabledMetric.setGranularity(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return enabledMetric;
                }
            }
        }
    }

    private static EnabledMetricStaxUnmarshaller instance;

    public static EnabledMetricStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new EnabledMetricStaxUnmarshaller();
        return instance;
    }
}
